pub struct SpannerBackend { /* private fields */ }Expand description
Google Cloud Spanner-backed backend.
Implementations
Sourceimpl SpannerBackend
impl SpannerBackend
Sourcepub async fn connect(
database: &str,
config: ClientConfig,
) -> Result<Self, Error>
pub async fn connect( database: &str, config: ClientConfig, ) -> Result<Self, Error>
Connect to a Spanner database resource name using a caller-provided config.
Sourcepub fn with_read_parallelism(self, read_parallelism: usize) -> Self
pub fn with_read_parallelism(self, read_parallelism: usize) -> Self
Set the read parallelism advertised to async prolly traversals.